package main

import (
	"net/http"

	"go.uber.org/zap"
)

var logger *zap.Logger
var sugarLogger *zap.SugaredLogger

func InitLogger() {
	logger, _ = zap.NewProduction()
	sugarLogger = logger.Sugar().With(zap.String("type", "sugar"))
}

func simpleHttpGet(url string) {
	resp, err := http.Get(url)
	if err != nil {
		logger.Error(
			"Error fetching url..",
			zap.String("url", url),
			zap.Error(err))
		sugarLogger.With(zap.String("url", url), zap.Error(err)).
			Error("Error fetching url..")
	} else {
		logger.Info("Success..",
			zap.String("statusCode", resp.Status), // zapcore.Field 本质是一组键值对参数
			zap.String("url", url))
		sugarLogger.With(zap.String("statusCode", resp.Status), zap.String("url", url)).
			Info("Success..")
		resp.Body.Close()
	}
}

func main() {
	InitLogger()
	defer logger.Sync()
	simpleHttpGet("www.xiexianbin.cn")
	simpleHttpGet("https://www.xiexianbin.cn")
}
